@@ -28,7 +28,8 @@
 
 int main(int argc, char** argv)
 {
-    QApplication app(argc, argv);
+    QGuiApplication app(argc, argv);
+    app.setQuitOnLastWindowClosed(false);
     KLocalizedString::setApplicationDomain("plasma-discover-exporter");
     KAboutData about(QStringLiteral("muonexporter"), i18n("Muon Exporter"), version, QString(),
                      KAboutLicense::GPL, i18n("©2013 Aleix Pol Gonzalez"), QString());
@@ -43,8 +44,6 @@ int main(int argc, char** argv)
         parser.addPositionalArgument(QStringLiteral("file"), i18n("File to which we'll export"));
         DiscoverBackendsFactory::setupCommandLine(&parser);
         about.setupCommandLine(&parser);
-        parser.addHelpOption();
-        parser.addVersionOption();
         parser.process(app);
         about.processCommandLine(&parser);
         DiscoverBackendsFactory::processCommandLine(&parser, false);
