@@ -151,7 +151,65 @@ bool FlatpakSourcesBackend::removeSource(const QString &id)
         FlatpakSourceItem *sourceItem = static_cast<FlatpakSourceItem*>(sourceIt);
         g_autoptr(GCancellable) cancellable = g_cancellable_new();
         g_autoptr(GError) error = nullptr;
-        if (flatpak_installation_remove_remote(sourceItem->flatpakInstallation(), id.toUtf8().constData(), cancellable, &error)) {
+        const auto installation = sourceItem->flatpakInstallation();
+
+        g_autoptr(GPtrArray) refs = flatpak_installation_list_remote_refs_sync(installation, id.toUtf8().constData(), cancellable, &error);
+        QHash<QString, QStringList> toRemoveHash;
+        toRemoveHash.reserve(refs->len);
+        QStringList toRemoveRefs;
+        toRemoveRefs.reserve(refs->len);
+        FlatpakBackend* backend = qobject_cast<FlatpakBackend*>(parent());
+        for (uint i = 0; i < refs->len; i++) {
+            FlatpakRef *ref= FLATPAK_REF(g_ptr_array_index(refs, i));
+
+            g_autoptr(GError) error = nullptr;
+            FlatpakInstalledRef* installedRef = flatpak_installation_get_installed_ref(installation, flatpak_ref_get_kind(ref), flatpak_ref_get_name(ref), flatpak_ref_get_arch(ref), flatpak_ref_get_branch(ref), cancellable, &error);
+            if (installedRef) {
+                auto res = backend->getAppForInstalledRef(installation, installedRef);
+                const auto name = QString::fromUtf8(flatpak_ref_get_name(ref));
+                const auto refString = QString::fromUtf8(flatpak_ref_format_ref(ref));
+                if (!name.endsWith(QLatin1String(".Locale"))) {
+                    if (res)
+                        toRemoveHash[res->name()] << refString;
+                    else
+                        toRemoveHash[refString] << refString;
+                }
+                toRemoveRefs << refString;
+            }
+        }
+        QStringList toRemove;
+        toRemove.reserve(toRemoveHash.count());
+        for (auto it = toRemoveHash.constBegin(), itEnd = toRemoveHash.constEnd(); it != itEnd; ++it) {
+            if (it.value().count() > 1)
+                toRemove << QStringLiteral("%1 - %2").arg(it.key(), it.value().join(QLatin1String(", ")));
+            else
+                toRemove << it.key();
+        }
+        toRemove.sort();
+
+        if (!toRemove.isEmpty()) {
+            m_proceedFunctions.push([this, toRemoveRefs, installation, id] {
+                g_autoptr(GError) localError = nullptr;
+                g_autoptr(GCancellable) cancellable = g_cancellable_new();
+                g_autoptr(FlatpakTransaction) transaction = flatpak_transaction_new_for_installation(installation, cancellable, &localError);
+                for (const QString& instRef : qAsConst(toRemoveRefs)) {
+                    const QByteArray refString = instRef.toUtf8();
+                    flatpak_transaction_add_uninstall(transaction, refString.constData(), &localError);
+                    if (localError)
+                        return;
+                }
+
+                if (flatpak_transaction_run(transaction, cancellable, &localError)) {
+                    removeSource(id);
+                }
+            });
+
+
+            Q_EMIT proceedRequest(i18n("Removing '%1'", id), i18n("To remove this repository, the following applications must be uninstalled:<ul><li>%1</li></ul>", toRemove.join(QStringLiteral("</li><li>"))));
+            return false;
+        }
+
+        if (flatpak_installation_remove_remote(installation, id.toUtf8().constData(), cancellable, &error)) {
             m_sources->removeRow(sourceItem->row());
 
             if (m_sources->rowCount() == 0) {
@@ -159,11 +217,11 @@ bool FlatpakSourcesBackend::removeSource(const QString &id)
             }
             return true;
         } else {
-            qWarning() << "Failed to remove " << id << " remote repository:" << error->message;
+            Q_EMIT passiveMessage(i18n("Failed to remove %1 remote repository: %2", id, QString::fromUtf8(error->message)));
             return false;
         }
     } else {
-        qWarning() << "couldn't find " << id;
+        Q_EMIT passiveMessage(i18n("Could not find %1", id));
         return false;
     }
 
@@ -260,6 +318,9 @@ void FlatpakSourcesBackend::addRemote(FlatpakRemote *remote, FlatpakInstallation
     it->setData(remoteUrl.isLocalFile() ? remoteUrl.toLocalFile() : remoteUrl.host(), Qt::ToolTipRole);
     it->setData(remoteUrl, Qt::StatusTipRole);
     it->setData(id, IdRole);
+#if FLATPAK_CHECK_VERSION(1,4,0)
+    it->setData(QString::fromUtf8(flatpak_remote_get_icon(remote)), IconUrlRole);
+#endif
     it->setFlatpakInstallation(installation);
 
     int idx = -1;
@@ -321,3 +382,13 @@ int FlatpakSourcesBackend::originIndex(const QString& sourceId) const
     auto item = sourceById(sourceId);
     return item ? item->row() : INT_MAX;
 }
+
+void FlatpakSourcesBackend::cancel()
+{
+    m_proceedFunctions.pop();
+}
+
+void FlatpakSourcesBackend::proceed()
+{
+    m_proceedFunctions.pop()();
+}
